@@ -44,11 +44,14 @@ class Config
   int rivendellNormalizationLevel() const;
   int rivendellAutotrimLevel() const;
   QString pathsEasDataDirectory() const;
+  QString pathsEasBackupDirectory() const;
   QString pathsEasMessageExtension() const;
   QStringList pathsEasMessageExtensionFilter();
   unsigned pathsRlmReceivePort() const;
   int introCart(const QString &code) const;
   int outroCart(const QString &code) const;
+  int liveassistIntroCart(const QString &code) const;
+  int liveassistOutroCart(const QString &code) const;
   QString dump() const;
   bool load();
   void clear();
@@ -69,11 +72,14 @@ class Config
   int conf_rivendell_normalization_level;
   int conf_rivendell_autotrim_level;
   QString conf_paths_eas_data_directory;
+  QString conf_paths_eas_backup_directory;
   QString conf_paths_eas_message_extension;
   QStringList conf_paths_eas_message_extension_filter;
   unsigned conf_paths_rlm_receive_port;
   QMap<QString,int> conf_intro_carts;
   QMap<QString,int> conf_outro_carts;
+  QMap<QString,int> conf_liveassist_intro_carts;
+  QMap<QString,int> conf_liveassist_outro_carts;
   QString conf_user_agent;
 };
 
