@@ -120,8 +120,7 @@ MainWidget::MainWidget(QWidget *parent)
   connect(main_auto_button,SIGNAL(clicked()),this,SLOT(autoData()));
   connect(main_auto_button,SIGNAL(quitRequested()),this,SLOT(quit()));
 
-  main_livesend_button=
-    new QPushButton(tr("Send to Log")+"\n("+tr("LIVE")+")",this);
+  main_livesend_button=new QPushButton(tr("Send to Log"),this);
   main_livesend_button->setFont(bold_font);
   connect(main_livesend_button,SIGNAL(clicked()),this,SLOT(liveSendData()));
   main_livesend_button->setDisabled(true);
@@ -131,6 +130,7 @@ MainWidget::MainWidget(QWidget *parent)
   main_cannedsend_button->setFont(bold_font);
   connect(main_cannedsend_button,SIGNAL(clicked()),this,SLOT(cannedSendData()));
   main_cannedsend_button->setDisabled(true);
+  main_cannedsend_button->hide();
 
   //
   // Alerts
@@ -191,34 +191,41 @@ void MainWidget::liveSendData()
     //
     // Load from the bottom up
     //
-    SendRml(QString().sprintf("PX %d %d %d PLAY!",    // Outro Cart
-			      1,
-			      main_config->rivendellLiveassistFriendlyOutroCart(),offset));
+    if(main_config->liveassistOutroCart(alert->easType())!=0) {
+      SendRml(QString().sprintf("PX %d %d %d PLAY!",    // Outro Cart
+				1,
+				main_config->
+				liveassistOutroCart(alert->easType()),
+				offset));
+      button->setLastCart(main_config->liveassistOutroCart(alert->easType()));
+    }
+    else {
+      button->setLastCart(alert->eomCart());
+    }
 
     SendRml(QString().sprintf("PX %d %d %d STOP!",    // EOM
 			      1,
 			      alert->eomCart(),offset));
     button->setLastCart(alert->eomCart());
 
-    if(alert->attentionCart()!=0) {
-      SendRml(QString().sprintf("PX %d %d %d PLAY!",    // Silence
-				1,
-				alert->silenceCart(),offset));
+    if(alert->messageCart()!=0) {
       SendRml(QString().sprintf("PX %d %d %d PLAY!",    // Attention Signal
 				1,
 				alert->attentionCart(),offset));
-      SendRml(QString().sprintf("PX %d %d %d PLAY!",    // Silence
-				1,
-				alert->silenceCart(),offset));
     }
 
     SendRml(QString().sprintf("PX %d %d %d PLAY!",    // Header
 			      1,
 			      alert->headerCart(),offset));
 
-    SendRml(QString().sprintf("PX %d %d %d STOP!",    // Intro
-			      1,
-			      main_config->rivendellLiveassistFriendlyIntroCart(),offset));
+    if(main_config->rivendellLiveassistFriendlyIntroCart()!=0) {
+      SendRml(QString().sprintf("PX %d %d %d STOP!",    // Intro Cart
+				1,
+				main_config->
+				liveassistIntroCart(alert->easType()),
+				offset));
+    }
+
     main_alert_buttons[main_selected_alert_id]->setStatus(AlertButton::Sent);
   }
 }
@@ -246,18 +253,9 @@ void MainWidget::cannedSendData()
       SendRml(QString().sprintf("PX %d %d %d PLAY!",    // Message
 				1,
 				alert->messageCart(),offset));
-    }
-
-    if(alert->attentionCart()!=0) {
-      SendRml(QString().sprintf("PX %d %d %d PLAY!",    // Silence
-				1,
-				alert->silenceCart(),offset));
       SendRml(QString().sprintf("PX %d %d %d PLAY!",    // Attention Signal
 				1,
 				alert->attentionCart(),offset));
-      SendRml(QString().sprintf("PX %d %d %d PLAY!",    // Silence
-				1,
-				alert->silenceCart(),offset));
     }
 
     SendRml(QString().sprintf("PX %d %d %d PLAY!",    // Header
@@ -300,18 +298,9 @@ void MainWidget::autoSendData(int id)
       SendRml(QString().sprintf("PX %d %d %d PLAY!",    // Message
 				1,
 				alert->messageCart(),offset));
-    }
-
-    if(alert->attentionCart()!=0) {
-      SendRml(QString().sprintf("PX %d %d %d PLAY!",    // Silence
-				1,
-				alert->silenceCart(),offset));
       SendRml(QString().sprintf("PX %d %d %d PLAY!",    // Message
 				1,
 				alert->attentionCart(),offset));
-      SendRml(QString().sprintf("PX %d %d %d PLAY!",    // Silence
-				1,
-				alert->silenceCart(),offset));
     }
 
     SendRml(QString().sprintf("PX %d %d %d PLAY!",    // Header
@@ -408,18 +397,20 @@ void MainWidget::alertClosedData(int id)
     }
     if(alert->attentionCart()!=0) {
       main_config->removeCart(alert->attentionCart(),&err_msg);
-      main_config->removeCart(alert->silenceCart(),&err_msg);
     }
     QString filename=alert->filename();
-    unlink((main_config->pathsEasDataDirectory()+"/"+filename).toUtf8());
+    RetireAlertFile(filename);
     if(!alert->headerAudio().isEmpty()) {
-      unlink((main_config->pathsEasDataDirectory()+"/"+alert->headerAudio()).toUtf8());
+      RetireAlertFile(alert->headerAudio());
+    }
+    if(!alert->attentionAudio().isEmpty()) {
+      RetireAlertFile(alert->attentionAudio());
     }
     if(!alert->messageAudio().isEmpty()) {
-      unlink((main_config->pathsEasDataDirectory()+"/"+alert->messageAudio()).toUtf8());
+      RetireAlertFile(alert->messageAudio());
     }
     if(!alert->eomAudio().isEmpty()) {
-      unlink((main_config->pathsEasDataDirectory()+"/"+alert->eomAudio()).toUtf8());
+      RetireAlertFile(alert->eomAudio());
     }
     delete alert;
     main_alerts.remove(filename);
@@ -480,9 +471,6 @@ void MainWidget::quit()
       if(alert->attentionCart()!=0) {
 	main_config->removeCart(alert->attentionCart(),&err_msg);
       }
-      if(alert->silenceCart()!=0) {
-	main_config->removeCart(alert->silenceCart(),&err_msg);
-      }
     }
   }
 
@@ -502,8 +490,8 @@ void MainWidget::resizeEvent(QResizeEvent *e)
 
   main_text_text->setGeometry(10,59,2*w/3,h-129);
 
-  main_livesend_button->setGeometry(40,h-60,120,50);
-  main_cannedsend_button->setGeometry(180,h-60,120,50);
+  main_livesend_button->setGeometry(40,h-60,200,50);
+  //  main_cannedsend_button->setGeometry(180,h-60,120,50);
 
   for(int i=0;i<EASP_ALERT_QUAN;i++) {
     main_alert_buttons[i]->setGeometry(2*w/3+20,
@@ -596,26 +584,6 @@ bool MainWidget::ProcessNewAlert(Alert *alert)
       else {
 	alert->setEomCart(cartnum);
       }
-      if(!alert->attentionAudio().isEmpty()) {
-	if((cartnum=main_config->
-	    importCart("*** EAS ATTENTION SIGNAL *** ["+alert->title()+"]",
-		       alert->attentionAudio(),&err_msg))==0) {
-	  button->setStatus(AlertButton::Error);
-	  button->addStatusText("Missing attention signal audio ["+err_msg+"]. ");
-	}
-	else {
-	  alert->setAttentionCart(cartnum);
-	}
-	if((cartnum=main_config->
-	    importCart("*** EAS SILENCE *** ["+alert->title()+"]",
-		       "/usr/share/easpanel/silence.wav",&err_msg))==0) {
-	  button->setStatus(AlertButton::Error);
-	  button->addStatusText("Missing silence audio ["+err_msg+"]. ");
-	}
-	else {
-	  alert->setSilenceCart(cartnum);
-	}
-      }
       if(!alert->messageAudio().isEmpty()) {
 	if((cartnum=main_config->
 	    importCart("*** EAS MESSAGE *** ["+alert->title()+"]",
@@ -625,6 +593,15 @@ bool MainWidget::ProcessNewAlert(Alert *alert)
 	}
 	else {
 	  alert->setMessageCart(cartnum);
+	  if((cartnum=main_config->
+	      importCart("*** EAS ATTENTION SIGNAL *** ["+alert->title()+"]",
+			 "/usr/share/easpanel/attention.wav",&err_msg))==0) {
+	    button->setStatus(AlertButton::Error);
+	    button->addStatusText("Missing attention signal audio ["+err_msg+"]. ");
+	  }
+	  else {
+	    alert->setAttentionCart(cartnum);
+	  }
 	}
       }
       if(i==main_selected_alert_id) {
@@ -660,11 +637,15 @@ void MainWidget::DisplayAlertButton(AlertButton *button)
   }
   button->setSelected(true);
   main_selected_alert_id=button->id();
+  main_livesend_button->setDisabled(main_auto||(alert==NULL)||
+				    (button->status()==AlertButton::Error));
+  /*
   main_livesend_button->setDisabled(main_auto||(alert==NULL)||
 				    (alert->messageCart()==0)||
 				    (button->status()==AlertButton::Error));
   main_cannedsend_button->setDisabled(main_auto||(alert==NULL)||
 				      (button->status()==AlertButton::Error));
+  */
 }
 
 
@@ -723,6 +704,18 @@ bool MainWidget::AlertLoaded() const
 }
 
 
+void MainWidget::RetireAlertFile(const QString &filename) const
+{
+  if(main_config->pathsEasBackupDirectory().isEmpty()) {
+    unlink((main_config->pathsEasDataDirectory()+"/"+filename).toUtf8());
+  }
+  else {
+    rename((main_config->pathsEasDataDirectory()+"/"+filename).toUtf8(),
+	   (main_config->pathsEasBackupDirectory()+"/"+filename).toUtf8());
+  }
+}
+
+
 int main(int argc,char *argv[])
 {
   QApplication::setStyle("Plastique");
